@@ -3,6 +3,7 @@ use crate::{
     traits::Slugify,
 };
 pub use text_utils::slugify;
+use crate::nodes::Header;
 
 impl Slugify for ASTNodes {
     fn slugify(&self) -> String {
@@ -31,6 +32,12 @@ impl Slugify for ASTKind {
     }
 }
 
+impl Slugify for Header {
+    fn slugify(&self) -> String {
+        todo!()
+    }
+}
+
 impl Slugify for String {
     fn slugify(&self) -> String {
         slugify!(self)
